pub fn run_tactics(state: ProofState, tactics: &[Node]) -> TacticRunResultExpand description
Apply link tactics to a proof state, stopping at the first failing tactic.
pub fn run_tactics(state: ProofState, tactics: &[Node]) -> TacticRunResultApply link tactics to a proof state, stopping at the first failing tactic.