pub fn run_tactics_with_options(
state: ProofState,
tactics: &[Node],
options: TacticOptions,
) -> TacticRunResultExpand description
Apply link tactics with configured rewrite rules, stopping at the first failing tactic.
pub fn run_tactics_with_options(
state: ProofState,
tactics: &[Node],
options: TacticOptions,
) -> TacticRunResultApply link tactics with configured rewrite rules, stopping at the first failing tactic.