pub fn simplify_with_options(
goal: &Node,
rules: &[Node],
options: SimplifyOptions,
) -> Result<SimplifyResult, Diagnostic>Expand description
Repeatedly apply rules until no rule changes the term or the guard fires.
pub fn simplify_with_options(
goal: &Node,
rules: &[Node],
options: SimplifyOptions,
) -> Result<SimplifyResult, Diagnostic>Repeatedly apply rules until no rule changes the term or the guard fires.