pub struct ActiveImplementationDescriptor {
pub construct: String,
pub foundation: Option<String>,
pub implementation: Option<String>,
pub status: Option<String>,
pub semantic_status: Option<String>,
pub depends_on: Vec<String>,
}Expand description
Active implementation selected by the current foundation scope for a
construct such as and or not. This is the behaviour-facing counterpart
to the global root-construct descriptor: strict pure-links mode consults
it before falling back to the global registry.
Fields
construct: Stringfoundation: Option<String>implementation: Option<String>status: Option<String>semantic_status: Option<String>depends_on: Vec<String>Trait Implementations
Sourceimpl Clone for ActiveImplementationDescriptor
impl Clone for ActiveImplementationDescriptor
Sourcefn clone(&self) -> ActiveImplementationDescriptor
fn clone(&self) -> ActiveImplementationDescriptor
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for ActiveImplementationDescriptor
impl Default for ActiveImplementationDescriptor
Sourcefn default() -> ActiveImplementationDescriptor
fn default() -> ActiveImplementationDescriptor
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for ActiveImplementationDescriptor
impl PartialEq for ActiveImplementationDescriptor
Sourcefn eq(&self, other: &ActiveImplementationDescriptor) -> bool
fn eq(&self, other: &ActiveImplementationDescriptor) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ActiveImplementationDescriptor