pub struct DefineClause {
pub pattern: Vec<Node>,
pub body: Node,
}Expand description
One (case <pattern-args> <body>) clause of a (define …) declaration.
Fields
pattern: Vec<Node>The clause’s pattern arguments — the children of the parenthesised pattern list, in left-to-right order.
body: NodeThe clause body, which may contain recursive references to the declared name.