pub fn eval_nat_term(env: &Env, node: &Node) -> Result<EvalNatResult, String>
Normalize a closed Peano term by dispatching through active links-level computation rules. Host arithmetic is only used by the final renderer.